==> ghoneycutt-nscd-1.15.0.tar.gz: ghoneycutt-nscd-1.15.0/CHANGELOG.md <==
# Changelog

## [v1.15.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.15.0) (2020-10-07)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.14.0...v1.15.0)

**Merged pull requests:**

- Bump stdlib dependency \< 7.0.0 to comply with the latest version [\#70](https://github.com/ghoneycutt/puppet-module-nscd/pull/70) ([mat1010](https://github.com/mat1010))

## [v1.14.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.14.0) (2020-06-16)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.13.0...v1.14.0)

**Closed issues:**

- Amazon Linux version number style differences with different Facter versions. [\#54](https://github.com/ghoneycutt/puppet-module-nscd/issues/54)
- make repository update before installing nscd [\#11](https://github.com/ghoneycutt/puppet-module-nscd/issues/11)

**Merged pull requests:**

- Support el8 [\#69](https://github.com/ghoneycutt/puppet-module-nscd/pull/69) ([anders-larsson](https://github.com/anders-larsson))

## [v1.13.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.13.0) (2019-05-10)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.12.0...v1.13.0)

**Closed issues:**

- Add support for SLES 15  [\#59](https://github.com/ghoneycutt/puppet-module-nscd/issues/59)

**Merged pull requests:**

- Use correct ruby versions in CI [\#66](https://github.com/ghoneycutt/puppet-module-nscd/pull/66) ([ghoneycutt](https://github.com/ghoneycutt))
- Add support for SuSE SLES 15 [\#63](https://github.com/ghoneycutt/puppet-module-nscd/pull/63) ([ghoneycutt](https://github.com/ghoneycutt))
- Only test Puppet v3 with the latest ruby for that release \(2.1.9\) [\#61](https://github.com/ghoneycutt/puppet-module-nscd/pull/61) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.12.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.12.0) (2019-01-04)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.11.0...v1.12.0)

**Merged pull requests:**

- Add support for Puppet 5 & 6 [\#58](https://github.com/ghoneycutt/puppet-module-nscd/pull/58) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.11.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.11.0) (2017-12-27)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.10.0...v1.11.0)

**Merged pull requests:**

- Fix testing [\#57](https://github.com/ghoneycutt/puppet-module-nscd/pull/57) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.10.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.10.0) (2017-04-17)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.9.1...v1.10.0)

**Closed issues:**

- Depreication warnings. [\#49](https://github.com/ghoneycutt/puppet-module-nscd/issues/49)
- Numbers or strings? [\#45](https://github.com/ghoneycutt/puppet-module-nscd/issues/45)

**Merged pull requests:**

- Amazon linux 2017 [\#52](https://github.com/ghoneycutt/puppet-module-nscd/pull/52) ([ghoneycutt](https://github.com/ghoneycutt))
- Support Puppet \>= 4.10 [\#50](https://github.com/ghoneycutt/puppet-module-nscd/pull/50) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.9.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.9.1) (2016-11-04)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.9.0...v1.9.1)

**Merged pull requests:**

- Explicitly use puppet-lint v2 [\#48](https://github.com/ghoneycutt/puppet-module-nscd/pull/48) ([ghoneycutt](https://github.com/ghoneycutt))
- Explicit use of strings for all numbers in documentation. [\#47](https://github.com/ghoneycutt/puppet-module-nscd/pull/47) ([alan-schwarzenberger](https://github.com/alan-schwarzenberger))

## [v1.9.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.9.0) (2016-09-01)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.8.0...v1.9.0)

**Closed issues:**

- Amazon linux support [\#41](https://github.com/ghoneycutt/puppet-module-nscd/issues/41)
- operatingsystemmajrelease not available on SLES 11 [\#33](https://github.com/ghoneycutt/puppet-module-nscd/issues/33)

**Merged pull requests:**

- Improve testing [\#46](https://github.com/ghoneycutt/puppet-module-nscd/pull/46) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.8.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.8.0) (2016-05-09)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.7.0...v1.8.0)

**Merged pull requests:**

- Support amazon 2015 2016 [\#44](https://github.com/ghoneycutt/puppet-module-nscd/pull/44) ([ghoneycutt](https://github.com/ghoneycutt))
- Continue supporting ruby 1.8.7 by pinning the version of rake [\#43](https://github.com/ghoneycutt/puppet-module-nscd/pull/43) ([ghoneycutt](https://github.com/ghoneycutt))
- Add rubocop support to lint spec tests and make recommended changes [\#40](https://github.com/ghoneycutt/puppet-module-nscd/pull/40) ([ghoneycutt](https://github.com/ghoneycutt))
- add space into netgroup section [\#39](https://github.com/ghoneycutt/puppet-module-nscd/pull/39) ([ofsole](https://github.com/ofsole))
- move empty lines into nscd.conf sections [\#38](https://github.com/ghoneycutt/puppet-module-nscd/pull/38) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.7.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.7.0) (2015-10-05)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.6.1...v1.7.0)

**Merged pull requests:**

- re-rebase solaris support [\#37](https://github.com/ghoneycutt/puppet-module-nscd/pull/37) ([Phil-Friderici](https://github.com/Phil-Friderici))
- rebase solaris support [\#36](https://github.com/ghoneycutt/puppet-module-nscd/pull/36) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.6.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.6.1) (2015-09-18)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.6.0...v1.6.1)

**Merged pull requests:**

- Fix Travis-ci matrix so that each feature release is tested [\#35](https://github.com/ghoneycutt/puppet-module-nscd/pull/35) ([ghoneycutt](https://github.com/ghoneycutt))
- use $::operatingsystemrelease instead of $::operatingsystemmajrelease for Suse [\#34](https://github.com/ghoneycutt/puppet-module-nscd/pull/34) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.6.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.6.0) (2015-07-14)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.5.0...v1.6.0)

**Merged pull requests:**

- Use operatingsystemmajrelease fact instead of lsbmajdistrelease [\#32](https://github.com/ghoneycutt/puppet-module-nscd/pull/32) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.5.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.5.0) (2015-06-24)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.4.0...v1.5.0)

**Merged pull requests:**

- Support Puppet v4 [\#30](https://github.com/ghoneycutt/puppet-module-nscd/pull/30) ([ghoneycutt](https://github.com/ghoneycutt))
- Support future parser on Puppet v3 [\#29](https://github.com/ghoneycutt/puppet-module-nscd/pull/29) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.4.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.4.0) (2015-06-24)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.3.0...v1.4.0)

**Merged pull requests:**

- Add support for SUSE SLE12 [\#28](https://github.com/ghoneycutt/puppet-module-nscd/pull/28) ([jwennerberg](https://github.com/jwennerberg))

## [v1.3.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.3.0) (2015-04-14)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.2.1...v1.3.0)

**Merged pull requests:**

- Add support for OpenSUSE 13.1 [\#27](https://github.com/ghoneycutt/puppet-module-nscd/pull/27) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.2.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.2.1) (2015-04-02)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.2.0...v1.2.1)

**Merged pull requests:**

- Prep v1.2.1 [\#25](https://github.com/ghoneycutt/puppet-module-nscd/pull/25) ([ghoneycutt](https://github.com/ghoneycutt))
- Changed outdated type-function to is\_\<type\>. [\#24](https://github.com/ghoneycutt/puppet-module-nscd/pull/24) ([ejabach](https://github.com/ejabach))
- add hint for QAS/VAS usage to README [\#23](https://github.com/ghoneycutt/puppet-module-nscd/pull/23) ([Phil-Friderici](https://github.com/Phil-Friderici))
- fix some default values in readme [\#16](https://github.com/ghoneycutt/puppet-module-nscd/pull/16) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.2.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.2.0) (2015-01-06)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.1.1...v1.2.0)

**Merged pull requests:**

- El7 support [\#22](https://github.com/ghoneycutt/puppet-module-nscd/pull/22) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.1.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.1.1) (2014-10-29)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.1.0) (2014-09-29)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.2...v1.1.0)

**Merged pull requests:**

- Support el5 and sles10 [\#12](https://github.com/ghoneycutt/puppet-module-nscd/pull/12) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.2](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.2) (2014-08-19)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.1...v1.0.2)

**Merged pull requests:**

- Change we we ignore module directory with puppet-lint to pass travis run... [\#10](https://github.com/ghoneycutt/puppet-module-nscd/pull/10) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.1) (2014-08-19)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.0...v1.0.1)

**Merged pull requests:**

- Maintenance [\#9](https://github.com/ghoneycutt/puppet-module-nscd/pull/9) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.0) (2014-02-17)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/f8886cb697540acf4592a9c3a73931450868c65a...v1.0.0)

**Merged pull requests:**

- Get to v1.0.0 [\#3](https://github.com/ghoneycutt/puppet-module-nscd/pull/3) ([ghoneycutt](https://github.com/ghoneycutt))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> ghoneycutt-nscd-2.1.0.tar.gz: ghoneycutt-nscd-2.1.0/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [v2.1.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v2.1.0) (2023-08-12)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v2.0.0...v2.1.0)

### Added

- New os rebase [\#78](https://github.com/ghoneycutt/puppet-module-nscd/pull/78) ([ghoneycutt](https://github.com/ghoneycutt))

## [v2.0.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v2.0.0) (2023-08-12)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.15.0...v2.0.0)

### Added

- Use tailoredautomation pdk-template [\#77](https://github.com/ghoneycutt/puppet-module-nscd/pull/77) ([ghoneycutt](https://github.com/ghoneycutt))
- Convert to PDK and add support for Puppet 8 [\#73](https://github.com/ghoneycutt/puppet-module-nscd/pull/73) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.15.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.15.0) (2020-10-07)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.14.0...v1.15.0)

### Merged pull requests:

- Bump stdlib dependency \< 7.0.0 to comply with the latest version [\#70](https://github.com/ghoneycutt/puppet-module-nscd/pull/70) ([mat1010](https://github.com/mat1010))

## [v1.14.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.14.0) (2020-06-16)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.13.0...v1.14.0)

### Merged pull requests:

- Support el8 [\#69](https://github.com/ghoneycutt/puppet-module-nscd/pull/69) ([anders-larsson](https://github.com/anders-larsson))

## [v1.13.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.13.0) (2019-05-10)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.12.0...v1.13.0)

### Merged pull requests:

- Use correct ruby versions in CI [\#66](https://github.com/ghoneycutt/puppet-module-nscd/pull/66) ([ghoneycutt](https://github.com/ghoneycutt))
- Add support for SuSE SLES 15 [\#63](https://github.com/ghoneycutt/puppet-module-nscd/pull/63) ([ghoneycutt](https://github.com/ghoneycutt))
- Only test Puppet v3 with the latest ruby for that release \(2.1.9\) [\#61](https://github.com/ghoneycutt/puppet-module-nscd/pull/61) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.12.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.12.0) (2019-01-04)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.11.0...v1.12.0)

### Merged pull requests:

- Add support for Puppet 5 & 6 [\#58](https://github.com/ghoneycutt/puppet-module-nscd/pull/58) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.11.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.11.0) (2017-12-27)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.10.0...v1.11.0)

### Merged pull requests:

- Fix testing [\#57](https://github.com/ghoneycutt/puppet-module-nscd/pull/57) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.10.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.10.0) (2017-04-17)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.9.1...v1.10.0)

### Merged pull requests:

- Amazon linux 2017 [\#52](https://github.com/ghoneycutt/puppet-module-nscd/pull/52) ([ghoneycutt](https://github.com/ghoneycutt))
- Support Puppet \>= 4.10 [\#50](https://github.com/ghoneycutt/puppet-module-nscd/pull/50) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.9.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.9.1) (2016-11-04)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.9.0...v1.9.1)

### Merged pull requests:

- Explicitly use puppet-lint v2 [\#48](https://github.com/ghoneycutt/puppet-module-nscd/pull/48) ([ghoneycutt](https://github.com/ghoneycutt))
- Explicit use of strings for all numbers in documentation. [\#47](https://github.com/ghoneycutt/puppet-module-nscd/pull/47) ([alan-schwarzenberger](https://github.com/alan-schwarzenberger))

## [v1.9.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.9.0) (2016-09-01)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.8.0...v1.9.0)

### Merged pull requests:

- Improve testing [\#46](https://github.com/ghoneycutt/puppet-module-nscd/pull/46) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.8.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.8.0) (2016-05-09)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.7.0...v1.8.0)

### Merged pull requests:

- Support amazon 2015 2016 [\#44](https://github.com/ghoneycutt/puppet-module-nscd/pull/44) ([ghoneycutt](https://github.com/ghoneycutt))
- Continue supporting ruby 1.8.7 by pinning the version of rake [\#43](https://github.com/ghoneycutt/puppet-module-nscd/pull/43) ([ghoneycutt](https://github.com/ghoneycutt))
- Add rubocop support to lint spec tests and make recommended changes [\#40](https://github.com/ghoneycutt/puppet-module-nscd/pull/40) ([ghoneycutt](https://github.com/ghoneycutt))
- add space into netgroup section [\#39](https://github.com/ghoneycutt/puppet-module-nscd/pull/39) ([ofsole](https://github.com/ofsole))
- move empty lines into nscd.conf sections [\#38](https://github.com/ghoneycutt/puppet-module-nscd/pull/38) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.7.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.7.0) (2015-10-05)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.6.1...v1.7.0)

### Merged pull requests:

- re-rebase solaris support [\#37](https://github.com/ghoneycutt/puppet-module-nscd/pull/37) ([Phil-Friderici](https://github.com/Phil-Friderici))
- rebase solaris support [\#36](https://github.com/ghoneycutt/puppet-module-nscd/pull/36) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.6.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.6.1) (2015-09-18)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.6.0...v1.6.1)

### Merged pull requests:

- Fix Travis-ci matrix so that each feature release is tested [\#35](https://github.com/ghoneycutt/puppet-module-nscd/pull/35) ([ghoneycutt](https://github.com/ghoneycutt))
- use $::operatingsystemrelease instead of $::operatingsystemmajrelease for Suse [\#34](https://github.com/ghoneycutt/puppet-module-nscd/pull/34) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.6.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.6.0) (2015-07-14)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.5.0...v1.6.0)

### Merged pull requests:

- Use operatingsystemmajrelease fact instead of lsbmajdistrelease [\#32](https://github.com/ghoneycutt/puppet-module-nscd/pull/32) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.5.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.5.0) (2015-06-24)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.4.0...v1.5.0)

### Merged pull requests:

- Support Puppet v4 [\#30](https://github.com/ghoneycutt/puppet-module-nscd/pull/30) ([ghoneycutt](https://github.com/ghoneycutt))
- Support future parser on Puppet v3 [\#29](https://github.com/ghoneycutt/puppet-module-nscd/pull/29) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.4.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.4.0) (2015-06-24)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.3.0...v1.4.0)

### Merged pull requests:

- Add support for SUSE SLE12 [\#28](https://github.com/ghoneycutt/puppet-module-nscd/pull/28) ([jwennerberg](https://github.com/jwennerberg))

## [v1.3.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.3.0) (2015-04-14)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.2.1...v1.3.0)

### Merged pull requests:

- Add support for OpenSUSE 13.1 [\#27](https://github.com/ghoneycutt/puppet-module-nscd/pull/27) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.2.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.2.1) (2015-04-02)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.2.0...v1.2.1)

### Merged pull requests:

- Prep v1.2.1 [\#25](https://github.com/ghoneycutt/puppet-module-nscd/pull/25) ([ghoneycutt](https://github.com/ghoneycutt))
- Changed outdated type-function to is\_\<type\>. [\#24](https://github.com/ghoneycutt/puppet-module-nscd/pull/24) ([mannbach](https://github.com/mannbach))
- add hint for QAS/VAS usage to README [\#23](https://github.com/ghoneycutt/puppet-module-nscd/pull/23) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.2.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.2.0) (2015-01-06)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.1.1...v1.2.0)

### Merged pull requests:

- El7 support [\#22](https://github.com/ghoneycutt/puppet-module-nscd/pull/22) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.1.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.1.1) (2014-10-29)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.1.0...v1.1.1)

### Merged pull requests:

- fix some default values in readme [\#16](https://github.com/ghoneycutt/puppet-module-nscd/pull/16) ([Phil-Friderici](https://github.com/Phil-Friderici))

## [v1.1.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.1.0) (2014-09-29)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.2...v1.1.0)

### Merged pull requests:

- Support el5 and sles10 [\#12](https://github.com/ghoneycutt/puppet-module-nscd/pull/12) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.2](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.2) (2014-08-19)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.1...v1.0.2)

### Merged pull requests:

- Change we we ignore module directory with puppet-lint to pass travis run... [\#10](https://github.com/ghoneycutt/puppet-module-nscd/pull/10) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.1](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.1) (2014-08-19)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/v1.0.0...v1.0.1)

### Merged pull requests:

- Maintenance [\#9](https://github.com/ghoneycutt/puppet-module-nscd/pull/9) ([ghoneycutt](https://github.com/ghoneycutt))

## [v1.0.0](https://github.com/ghoneycutt/puppet-module-nscd/tree/v1.0.0) (2014-02-17)

[Full Changelog](https://github.com/ghoneycutt/puppet-module-nscd/compare/f8886cb697540acf4592a9c3a73931450868c65a...v1.0.0)

### Merged pull requests:

- Get to v1.0.0 [\#3](https://github.com/ghoneycutt/puppet-module-nscd/pull/3) ([ghoneycutt](https://github.com/ghoneycutt))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
